
# pyChemEngg

> This is a python package to facilitate teaching of chemical engineering. The package is still in development stage. When complete, there will be support for different topics such as:

* Material Balances
* Heat Transfer
* Fluid Flow
* Thermodynamics
* Chemical Reaction Engineering
* Process Control


## Philosophy
> The *pyChemEngg* package has the following philosophy:
* The package should facilitate student learning. The package should not become a black box such that it hides the underlying fundamentals of chemical engineering. Instead the package should reinforce chemical engineering principles, stimulate students to think, promote curiosity, and make learning fun.


## Current status
* The package for material balances for physical processes (no chemical reaction) is complete.
* Currently the package for heat transfer is ~70% complete.


## General Information
* Chemical engineers are now expected to possess programming skills, and python is an attractive language popular in scientific and technical computing. 
* The *pyChemEngg* package will provide integrated learning experience and will exposes chemical engineering students to the python programming language throughout their degree program.

## Installation
* At the moment the package is empty and should not be installed.


## Contact
Created by [@profhsgill](https://github.com/profhsgill) - feel free to contact me!

## Licence
> This project is open source and available under the MIT license

